## usethis namespace: start
#' @useDynLib BayesfMRI, .registration = TRUE
#' @importFrom Rcpp evalCpp
## usethis namespace: end
"_PACKAGE"
